
#  X-Ray Fluorescence beamline (XRF)

**Ilaria Carlomagno** has kindly provided extensive user-oriented 
[documentation](https://www.elettra.eu/lightsources/elettra/elettra-beamlines/microfluorescence/useful-procedures.html)
on useful procedures and detailed description of the acquisition tools. 


## Troubleshooting

Fluorescence experiments are controlled by IAEA software running on their Windows machines. 
We can reach IAEA tango database from our network and vice-versa. 
IAEA Tango database is iaea-server.elettra.trieste.it:20000

XRF Monochromator is prone to malfunctions due to a very complex design. It includes
a collimator and a refocusing mirror in the same chamber with the monochromator. 
The monochromator has 5 channels: Si, InSb, HE, ME and LE. For the first two, the crystal 
separations may be regulated. Motor controllers include Galil, SmarAct, PI and Newfocus.

On the xrf-desktop-01 workstation the network speed has changed a few times from gigabit 
to the slowest setting, 10Kb/s. The cause is yet unknown. <-- Issue fixed in 2022.


## **Control system machines**

Beamline controls and EXAFS experiments run on Elettra hardware and software.
- **xrf-control-01.blcs.elettra.trieste.it**: Dismissed in 2023.

- **xrf-control-02.blcs.elettra.trieste.it**: Virtual machine that hosts the Tango database
(port 20000) and all the Tango devices (except the IAEA ones, see below). 
Ubuntu 18.04 and Tango-9.3.4. Login with the VUO account as on the latest installations.
Devices are deployed in /runtime/bin, configurations in /runtime/etc (user: controls).

- **iaea-server.elettra.eu**: is the old Windows PC located in the corner of the XRF control 
room. Remote access is only possible with TightVNC. Beamline staff has the login credentials.
Tango devices (all C++) for IAEA detectors and 7-axes manipulator run on another host that
is inside the hutch and accessed from this PC. 
An Astor-simulating application that starts and stops tango devices is running on the host. 
Regular Astor cannot be used due to the starter issues but Jive is available. TANGO_HOST is
iaea-server.elettra.trieste.it:20000

## **Beamline workstations**

Both xrf-desktop-01 and xrf-desktop-02 have been reinstalled in 2023 with the Ubuntu 18.04 LTS 
and Tango-9.3.4. Python3 versions of all important packages are available (PyTango, hdf, numpy...)
Login with the VUO credentials.

- **xrf-desktop-01.blcs.elettra.trieste.it**: Main workstation for controlling the
beamline and the EXAFS experiments. Logbook typically runs on this host.

- **xrf-desktop-02.blcs.elettra.trieste.it**: Backup workstation with the same 
setup as the main workstation but with a much smaller screen.

Both machines have VNC access used extensively by the beamline scientists.  
GUIs are deployed in /runtime/bin, configuration files in /runtime/etc (user: controls).

## **High level TANGO devices**

- **xrf/monochromator/energy**: Tango device for the monochromator used to set the energy.
The energy value is calculated from angle of incidence with the inversefunc method from the
pynverse library as the position to energy formula based on the monochromator kinematics is not 
invertible otherwise. The monochromator device controls channel selection, angle of incidence 
and crystal separation values, while the pitch and roll motors of each crystal are excluded
in the current implementation. An Executer script, xrf/monochromator/set_energy, is used to 
avoid backlash when changing energy to a lower value by setting an even lower value first. 
All the scans are performed by moving from lower to higher energies.

- **xrf/acquisition/exafs_scan**: An Executer script that controls the EXAFS scans. 
It is highly configurable and it runs either from its Taurus GUI or from a command line
tool that uses python properties files for its configuration. The acquisition is performed
by the **DonkiOrchestra**. Over the years additional scans have been added and are occasionlly
used like XRR, XSW.
For detailed information see: 
[Hot to run scans](https://www.elettra.eu/lightsources/elettra/elettra-beamlines/microfluorescence/how-to-run-exafs-xrr-and-xsw-scans.html)

## **High level CLI**

- **exafs_scan.py**: A command line tool found on the two workstations that configures 
and runs any number of EXAFS and other type scans. Also, it controls the HOS and 7-axes manipulator. 
It is entirely configurable with python's property files. For detailed information see: 
[Macros@XRF](https://www.elettra.eu/lightsources/elettra/elettra-beamlines/microfluorescence/macros-at-xrf.html)

## **Instrumentation TANGO devices**

The following Tango devices run on the IAEA server and are controlled/acquired by both 
IAEA and Elettra software:
- BrukerSpectometer : Bruker detector
- KeithleyPicoAmmeter : Photo-diode
- ElettraPicoAmmeter : BMS
- SevenAxesManipulator : controls the movements of 7 axes of the chamber manipulator.

Used only from IAEA GUI:
- AmptecSpettrometer : XRR (X-Ray Reflectivity) scans of theta/2theta. 
- XiaXmapSpectrometer : not in use.

## **Motion control Tango devices**

- AxisG2: it is the new Galil C++ Tango device from A. Abrami. 
All instances are configured so that the AxisInit command does the initialization.

- PiezoPiE871: a modified C++ Tango device from DESY for the two PI positioners 
that move pitch and roll of the first (Si111) crystal. Positioners are encoderless
and the initialization is perfomed by a DefinePosition(Value).

- NewFocusPicoAxis: A C++ Tango device for pitch and roll motors of all crystals 
except the Silicon. They are automatically initialized.

- SmaractMCS: A Python Tango device for MCS1 SmarAct positioner that moves the
InSb crystal separation. It must be initialized with FindReferenceMark command.
(If the motor cables were removed, a Calibrate command is necessary first.)

